You are viewing a plain text version of this content. The canonical link for it is here.
Posted to dev@commons.apache.org by ni...@apache.org on 2005/12/09 04:07:16 UTC

svn commit: r355334 - in /jakarta/commons/proper/resources/trunk: src/java/org/apache/commons/resources/impl/BasicMessage.java xdocs/index.xml

Author: niallp
Date: Thu Dec  8 19:07:05 2005
New Revision: 355334

URL: http://svn.apache.org/viewcvs?rev=355334&view=rev
Log:
Improve BasicMessage.toString() and minor doc corrections for Bugs 37830, 37831, 37845 - based on patches supplied by Christian Meder

Modified:
    jakarta/commons/proper/resources/trunk/src/java/org/apache/commons/resources/impl/BasicMessage.java
    jakarta/commons/proper/resources/trunk/xdocs/index.xml

Modified: jakarta/commons/proper/resources/trunk/src/java/org/apache/commons/resources/impl/BasicMessage.java
URL: http://svn.apache.org/viewcvs/jakarta/commons/proper/resources/trunk/src/java/org/apache/commons/resources/impl/BasicMessage.java?rev=355334&r1=355333&r2=355334&view=diff
==============================================================================
--- jakarta/commons/proper/resources/trunk/xdocs/index.xml (original)
+++ jakarta/commons/proper/resources/trunk/xdocs/index.xml Thu Dec  8 19:07:05 2005
@@ -59,7 +59,7 @@
             <code>Resources</code> instance.</li>
     </ul>
 
-    <p>Basic imlementations of the above are provided for resources contained
+    <p>Basic implementations of the above are provided for resources contained
        in property files, XML and databases(via JDBC). Implementations are
        also provided for use in a Web App environment.
     </p>
@@ -68,7 +68,7 @@
        and message lists:</p>
     <ul>
         <li><a href="apidocs/org/apache/commons/resources/Message.html">Message</a> 
-            An encapsulation of an individual messag, consisting of a message key,
+            An encapsulation of an individual message, consisting of a message key,
             and replacement values.</li>
         <li><a href="apidocs/org/apache/commons/resources/MessageList.html">MessageList</a> 
             A class that encapsulates a set of messages.</li>



---------------------------------------------------------------------
To unsubscribe, e-mail: commons-dev-unsubscribe@jakarta.apache.org
For additional commands, e-mail: commons-dev-help@jakarta.apache.org
--- jakarta/commons/proper/resources/trunk/src/java/org/apache/commons/resources/impl/BasicMessage.java (original)
+++ jakarta/commons/proper/resources/trunk/src/java/org/apache/commons/resources/impl/BasicMessage.java Thu Dec  8 19:07:05 2005
@@ -30,7 +30,7 @@
 /**
  * A basic implementation of the Message interface.
  * <p>
- * Orginally based on org.apache.http.action.ActionMessage, Revision 1.5.
+ * Orginally based on org.apache.struts.action.ActionMessage, Revision 1.5.
  */
 public class BasicMessage implements Serializable, Message {
 
@@ -58,7 +58,7 @@
     }
     
     /**
-     * Construct an action message with no replacement values.
+     * Construct a message with no replacement values.
      *
      * @param key Message key for this message
      */
@@ -70,7 +70,7 @@
     }
 
     /**
-     * Construct an action message with the specified replacement values.
+     * Construct a message with the specified replacement values.
      *
      * @param key Message key for this message
      * @param value0 First replacement value
@@ -83,7 +83,7 @@
     }
 
     /**
-     * Construct an action message with the specified replacement values.
+     * Construct a message with the specified replacement values.
      *
      * @param key Message key for this message
      * @param value0 First replacement value
@@ -97,7 +97,7 @@
     }
 
     /**
-     * Construct an action message with the specified replacement values.
+     * Construct a message with the specified replacement values.
      *
      * @param key Message key for this message
      * @param value0 First replacement value
@@ -113,7 +113,7 @@
     }
 
     /**
-     * Construct an action message with the specified replacement values.
+     * Construct a message with the specified replacement values.
      *
      * @param key Message key for this message
      * @param value0 First replacement value
@@ -129,7 +129,7 @@
     }
 
     /**
-     * Construct an action message with the specified replacement values.
+     * Construct a message with the specified replacement values.
      *
      * @param key Message key for this message
      * @param values Array of replacement values
@@ -190,11 +190,15 @@
     }
 
     /**
      * Returns a String in the format: key[value0, value1, etc].
      * @see java.lang.Object#toString()
      */
     public String toString() {
         StringBuffer buff = new StringBuffer();
+        if (this.resourcesName != null) {
+            buff.append(this.resourcesName);
+            buff.append(":"); 
+        }
         buff.append(this.key);
         buff.append("[");
 
@@ -190,11 +190,15 @@
 
     /**
-     * Returns a String in the format: key[value0, value1, etc].
+     * Returns a String in the format: resourcesName:key[value0, value1, etc]. 
      * @see java.lang.Object#toString()
      */

Modified: jakarta/commons/proper/resources/trunk/xdocs/index.xml
URL: http://svn.apache.org/viewcvs/jakarta/commons/proper/resources/trunk/xdocs/index.xml?rev=355334&r1=355333&r2=355334&view=diff
==============================================================================